.. _voxel image math functions:

Parallel math
------------------------

.. automodule:: rockverse.digitalrock.voxelimage._math
.. automethod:: rockverse.digitalrock.voxelimage.VoxelImage.math
.. automethod:: rockverse.digitalrock.voxelimage.VoxelImage.combine
